@@ -1,9 +1,9 @@
 package Text::Table::HTML::DataTables;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-11-05'; # DATE
+our $DATE = '2020-11-08'; # DATE
 our $DIST = 'Text-Table-HTML-DataTables'; # DIST
-our $VERSION = '0.005'; # VERSION
+our $VERSION = '0.006'; # VERSION
 
 use 5.010001;
 use strict;
@@ -38,47 +38,15 @@ sub table {
     push @table, "<head>\n";
 
     push @table, qq(<link rel="stylesheet" type="text/css" href="file://)._escape_uri("$dist_dir/datatables-1.10.22/datatables.css").qq(">\n);
-    #push @table, qq(<link rel="stylesheet" type="text/css" href="file://)._escape_uri("$dist_dir/Buttons-1.6.5/css/buttons.dataTables.css").qq(">\n);
-    push @table, qq(<link rel="stylesheet" type="text/css" href="file://)._escape_uri("$dist_dir/SearchBuilder-1.0.0/css/searchBuilder.dataTables.css").qq(">\n);
-
     push @table, qq(<script src="file://)._escape_uri("$dist_dir/jquery-2.2.4/jquery-2.2.4.min.js").qq("></script>\n);
     push @table, qq(<script src="file://)._escape_uri("$dist_dir/datatables-1.10.22/datatables.js").qq("></script>\n);
-    #push @table, qq(<script src="file://)._escape_uri("$dist_dir/Buttons-1.6.5/js/buttons.colVis.js").qq("></script>\n);
-    #push @table, qq(<script src="file://)._escape_uri("$dist_dir/Buttons-1.6.5/js/buttons.print.js").qq("></script>\n);
-    push @table, qq(<script src="file://)._escape_uri("$dist_dir/SearchBuilder-1.0.0/js/dataTables.searchBuilder.js").qq("></script>\n);
-    #push @table, qq(<script src="file://)._escape_uri("$dist_dir/SearchBuilder-1.0.0/js/searchBuilder.dataTables.js").qq("></script>\n);
-
-    # not yet
-    # <link rel="stylesheet" type="text/css" href="ColReorder-1.5.2/css/colReorder.dataTables.css"/>
-    # <link rel="stylesheet" type="text/css" href="FixedColumns-3.3.1/css/fixedColumns.dataTables.css"/>
-    # <link rel="stylesheet" type="text/css" href="FixedHeader-3.1.7/css/fixedHeader.dataTables.css"/>
-    # <link rel="stylesheet" type="text/css" href="KeyTable-2.5.3/css/keyTable.dataTables.css"/>
-
-    # <script type="text/javascript" src="Buttons-1.6.5/js/dataTables.buttons.js"></script>
-    # <script type="text/javascript" src="Buttons-1.6.5/js/buttons.colVis.js"></script>
-    # <script type="text/javascript" src="Buttons-1.6.5/js/buttons.print.js"></script>
-    # <script type="text/javascript" src="ColReorder-1.5.2/js/dataTables.colReorder.js"></script>
-    # <script type="text/javascript" src="FixedColumns-3.3.1/js/dataTables.fixedColumns.js"></script>
-    # <script type="text/javascript" src="FixedHeader-3.1.7/js/dataTables.fixedHeader.js"></script>
-    # <script type="text/javascript" src="KeyTable-2.5.3/js/dataTables.keyTable.js"></script>
 
     push @table, '<script>';
     my $dt_opts = {
         dom => 'lQfrtip',
-        #buttons => ['colVis', 'print'],
+        buttons => ['colvis', 'print'],
     };
     push @table, 'var dt_opts = ', JSON::PP::encode_json($dt_opts), '; ';
-#     push @table, q(dt_opts['searchBuilder'] = {conditions: {string: {
-# 	        '!contains': {
-# 	            conditionName: 'Does Not Contain',
-# 	            init: function (that, fn, preDefined) { return $('<input/>') },
-# 	            inputValue: null,
-# 	            isInputValid: null,
-# 	            search: function (value, comparison) {
-# 	                return !value.toLowerCase().includes(comparison[0].toLowerCase());
-# 	            }
-#                 }
-# }}}; );
     push @table, '$(document).ready(function() { $("table").DataTable(dt_opts); });';
     push @table, '</script>'."\n\n";
     push @table, "</head>\n\n";
@@ -153,7 +121,7 @@ Text::Table::HTML::DataTables - Generate HTML table with jQuery and DataTables p
 
 =head1 VERSION
 
-This document describes version 0.005 of Text::Table::HTML::DataTables (from Perl distribution Text-Table-HTML-DataTables), released on 2020-11-05.
+This document describes version 0.006 of Text::Table::HTML::DataTables (from Perl distribution Text-Table-HTML-DataTables), released on 2020-11-08.
 
 =head1 SYNOPSIS
 
@@ -176,7 +144,20 @@ load jQuery (L<http://jquery.com>) and the DataTables plugin
 (L<http://datatables.net>) from the local filesystem (distribution shared
 directory), so you can filter and sort the table in the browser.
 
-The example shown in the SYNOPSIS generates the following table:
+The datatables bundled in this distribution has the following characteristics:
+
+=over
+
+=item * Support negative search using dash prefix syntax ("-foo") a la Google
+
+To search for table rows that contain "foo", "bar" (in no particular order) and
+not "baz", you can enter in the search box:
+
+ foo bar -baz
+
+=back
+
+The example shown in the SYNOPSIS generates HTML code like the following:
 
  <link rel="stylesheet" type="text/css" href="file:///home/ujang/perl5/perlbrew/perls/perl-5.24.0/lib/site_perl/5.24.0/auto/share/dist/Text-Table-HTML-DataTables/datatables-1.10.13/css/jquery.dataTables.min.css">
  <script src="file:///home/ujang/perl5/perlbrew/perls/perl-5.24.0/lib/site_perl/5.24.0/auto/share/dist/Text-Table-HTML-DataTables/jquery-2.2.4/jquery-2.2.4.min.js"></script>
@@ -235,6 +216,8 @@ L<Text::Table::HTML>
 
 See also L<Bencher::Scenario::TextTableModules>.
 
+L<https://datatables.net>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
